from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.create_database_initial_cluster import CreateDatabaseInitialCluster





T = TypeVar("T", bound="CreateDatabase")


@_attrs_define
class CreateDatabase:
    """ 
        Attributes:
            name (str):
            initial_cluster (CreateDatabaseInitialCluster):
            provider (str):
            region (str):
     """

    name: str
    initial_cluster: 'CreateDatabaseInitialCluster'
    provider: str
    region: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        from ..models.create_database_initial_cluster import (
            CreateDatabaseInitialCluster,
        )
        name = self.name

        initial_cluster = self.initial_cluster.to_dict()

        provider = self.provider

        region = self.region


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "name": name,
            "initialCluster": initial_cluster,
            "provider": provider,
            "region": region,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.create_database_initial_cluster import (
            CreateDatabaseInitialCluster,
        )
        d = src_dict.copy()
        name = d.pop("name")

        initial_cluster = CreateDatabaseInitialCluster.from_dict(d.pop("initialCluster"))




        provider = d.pop("provider")

        region = d.pop("region")

        create_database = cls(
            name=name,
            initial_cluster=initial_cluster,
            provider=provider,
            region=region,
        )

        create_database.additional_properties = d
        return create_database

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.status import Status
from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.auto_stop import AutoStop





T = TypeVar("T", bound="Cluster")


@_attrs_define
class Cluster:
    """ 
        Attributes:
            status (Status):
            id (str):
            name (str):
            size (str):
            created_at (datetime.datetime):
            created_by (str):
            main_cluster (bool):
            deleted_at (Union[Unset, datetime.datetime]):
            deleted_by (Union[Unset, str]):
            auto_stop (Union[Unset, AutoStop]):
     """

    status: Status
    id: str
    name: str
    size: str
    created_at: datetime.datetime
    created_by: str
    main_cluster: bool
    deleted_at: Union[Unset, datetime.datetime] = UNSET
    deleted_by: Union[Unset, str] = UNSET
    auto_stop: Union[Unset, 'AutoStop'] = UNSET


    def to_dict(self) -> Dict[str, Any]:
        from ..models.auto_stop import AutoStop
        status = self.status.value

        id = self.id

        name = self.name

        size = self.size

        created_at = self.created_at.isoformat()

        created_by = self.created_by

        main_cluster = self.main_cluster

        deleted_at: Union[Unset, str] = UNSET
        if not isinstance(self.deleted_at, Unset):
            deleted_at = self.deleted_at.isoformat()

        deleted_by = self.deleted_by

        auto_stop: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.auto_stop, Unset):
            auto_stop = self.auto_stop.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "status": status,
            "id": id,
            "name": name,
            "size": size,
            "createdAt": created_at,
            "createdBy": created_by,
            "mainCluster": main_cluster,
        })
        if deleted_at is not UNSET:
            field_dict["deletedAt"] = deleted_at
        if deleted_by is not UNSET:
            field_dict["deletedBy"] = deleted_by
        if auto_stop is not UNSET:
            field_dict["autoStop"] = auto_stop

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.auto_stop import AutoStop
        d = src_dict.copy()
        status = Status(d.pop("status"))




        id = d.pop("id")

        name = d.pop("name")

        size = d.pop("size")

        created_at = isoparse(d.pop("createdAt"))




        created_by = d.pop("createdBy")

        main_cluster = d.pop("mainCluster")

        _deleted_at = d.pop("deletedAt", UNSET)
        deleted_at: Union[Unset, datetime.datetime]
        if isinstance(_deleted_at,  Unset):
            deleted_at = UNSET
        else:
            deleted_at = isoparse(_deleted_at)




        deleted_by = d.pop("deletedBy", UNSET)

        _auto_stop = d.pop("autoStop", UNSET)
        auto_stop: Union[Unset, AutoStop]
        if isinstance(_auto_stop,  Unset):
            auto_stop = UNSET
        else:
            auto_stop = AutoStop.from_dict(_auto_stop)




        cluster = cls(
            status=status,
            id=id,
            name=name,
            size=size,
            created_at=created_at,
            created_by=created_by,
            main_cluster=main_cluster,
            deleted_at=deleted_at,
            deleted_by=deleted_by,
            auto_stop=auto_stop,
        )

        return cluster




from http import HTTPStatus
from typing import (
    Any,
    Dict,
    List,
    Optional,
    Union,
    cast,
)

import httpx

from ... import errors
from ...client import (
    AuthenticatedClient,
    Client,
)
from ...models.user import User
from ...types import (
    UNSET,
    Response,
    Unset,
)


def _get_kwargs(
    account_id: str,
    *,
    filter_: Union[Unset, str] = UNSET,
    next_: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = UNSET,

) -> Dict[str, Any]:
    

    

    params: Dict[str, Any] = {}

    params["filter"] = filter_

    params["next"] = next_

    params["limit"] = limit


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/accounts/{account_id}/users".format(account_id=account_id,),
        "params": params,
    }


    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[List['User']]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in (_response_200):
            response_200_item = User.from_dict(response_200_item_data)



            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[List['User']]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    account_id: str,
    *,
    client: AuthenticatedClient,
    filter_: Union[Unset, str] = UNSET,
    next_: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = UNSET,

) -> Response[List['User']]:
    """ 
    Args:
        account_id (str):
        filter_ (Union[Unset, str]):
        next_ (Union[Unset, int]):
        limit (Union[Unset, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['User']]
     """


    kwargs = _get_kwargs(
        account_id=account_id,
filter_=filter_,
next_=next_,
limit=limit,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    account_id: str,
    *,
    client: AuthenticatedClient,
    filter_: Union[Unset, str] = UNSET,
    next_: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = UNSET,

) -> Optional[List['User']]:
    """ 
    Args:
        account_id (str):
        filter_ (Union[Unset, str]):
        next_ (Union[Unset, int]):
        limit (Union[Unset, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['User']
     """


    return sync_detailed(
        account_id=account_id,
client=client,
filter_=filter_,
next_=next_,
limit=limit,

    ).parsed

async def asyncio_detailed(
    account_id: str,
    *,
    client: AuthenticatedClient,
    filter_: Union[Unset, str] = UNSET,
    next_: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = UNSET,

) -> Response[List['User']]:
    """ 
    Args:
        account_id (str):
        filter_ (Union[Unset, str]):
        next_ (Union[Unset, int]):
        limit (Union[Unset, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['User']]
     """


    kwargs = _get_kwargs(
        account_id=account_id,
filter_=filter_,
next_=next_,
limit=limit,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    account_id: str,
    *,
    client: AuthenticatedClient,
    filter_: Union[Unset, str] = UNSET,
    next_: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = UNSET,

) -> Optional[List['User']]:
    """ 
    Args:
        account_id (str):
        filter_ (Union[Unset, str]):
        next_ (Union[Unset, int]):
        limit (Union[Unset, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['User']
     """


    return (await asyncio_detailed(
        account_id=account_id,
client=client,
filter_=filter_,
next_=next_,
limit=limit,

    )).parsed



from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.usage_additional_property_item import UsageAdditionalPropertyItem





T = TypeVar("T", bound="Usage")


@_attrs_define
class Usage:
    """ 
     """

    additional_properties: Dict[str, List['UsageAdditionalPropertyItem']] = _attrs_field(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        from ..models.usage_additional_property_item import UsageAdditionalPropertyItem
        
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = []
            for additional_property_item_data in prop:
                additional_property_item = additional_property_item_data.to_dict()
                field_dict[prop_name].append(additional_property_item)





        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.usage_additional_property_item import UsageAdditionalPropertyItem
        d = src_dict.copy()
        usage = cls(
        )


        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = []
            _additional_property = prop_dict
            for additional_property_item_data in (_additional_property):
                additional_property_item = UsageAdditionalPropertyItem.from_dict(additional_property_item_data)



                additional_property.append(additional_property_item)

            additional_properties[prop_name] = additional_property

        usage.additional_properties = additional_properties
        return usage

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> List['UsageAdditionalPropertyItem']:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: List['UsageAdditionalPropertyItem']) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.patch_user_databases import PatchUserDatabases





T = TypeVar("T", bound="PatchUser")


@_attrs_define
class PatchUser:
    """ 
        Attributes:
            role_id (Union[Unset, str]):
            databases (Union[Unset, PatchUserDatabases]):
            db_username (Union[Unset, str]):
     """

    role_id: Union[Unset, str] = UNSET
    databases: Union[Unset, 'PatchUserDatabases'] = UNSET
    db_username: Union[Unset, str] = UNSET


    def to_dict(self) -> Dict[str, Any]:
        from ..models.patch_user_databases import PatchUserDatabases
        role_id = self.role_id

        databases: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.databases, Unset):
            databases = self.databases.to_dict()

        db_username = self.db_username


        field_dict: Dict[str, Any] = {}
        field_dict.update({
        })
        if role_id is not UNSET:
            field_dict["roleID"] = role_id
        if databases is not UNSET:
            field_dict["databases"] = databases
        if db_username is not UNSET:
            field_dict["dbUsername"] = db_username

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.patch_user_databases import PatchUserDatabases
        d = src_dict.copy()
        role_id = d.pop("roleID", UNSET)

        _databases = d.pop("databases", UNSET)
        databases: Union[Unset, PatchUserDatabases]
        if isinstance(_databases,  Unset):
            databases = UNSET
        else:
            databases = PatchUserDatabases.from_dict(_databases)




        db_username = d.pop("dbUsername", UNSET)

        patch_user = cls(
            role_id=role_id,
            databases=databases,
            db_username=db_username,
        )

        return patch_user




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.connection_i_ps import ConnectionIPs





T = TypeVar("T", bound="ClusterConnection")


@_attrs_define
class ClusterConnection:
    """ 
        Attributes:
            dns (str):
            port (int):
            jdbc (str):
            ips (ConnectionIPs):
            db_username (str):
     """

    dns: str
    port: int
    jdbc: str
    ips: 'ConnectionIPs'
    db_username: str


    def to_dict(self) -> Dict[str, Any]:
        from ..models.connection_i_ps import ConnectionIPs
        dns = self.dns

        port = self.port

        jdbc = self.jdbc

        ips = self.ips.to_dict()

        db_username = self.db_username


        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "dns": dns,
            "port": port,
            "jdbc": jdbc,
            "ips": ips,
            "dbUsername": db_username,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.connection_i_ps import ConnectionIPs
        d = src_dict.copy()
        dns = d.pop("dns")

        port = d.pop("port")

        jdbc = d.pop("jdbc")

        ips = ConnectionIPs.from_dict(d.pop("ips"))




        db_username = d.pop("dbUsername")

        cluster_connection = cls(
            dns=dns,
            port=port,
            jdbc=jdbc,
            ips=ips,
            db_username=db_username,
        )

        return cluster_connection




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.extension_parameter_value import ExtensionParameterValue





T = TypeVar("T", bound="CreateExtensionInstance")


@_attrs_define
class CreateExtensionInstance:
    """ 
        Attributes:
            parameter_values (List['ExtensionParameterValue']):
     """

    parameter_values: List['ExtensionParameterValue']


    def to_dict(self) -> Dict[str, Any]:
        from ..models.extension_parameter_value import ExtensionParameterValue
        parameter_values = []
        for parameter_values_item_data in self.parameter_values:
            parameter_values_item = parameter_values_item_data.to_dict()
            parameter_values.append(parameter_values_item)






        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "parameterValues": parameter_values,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.extension_parameter_value import ExtensionParameterValue
        d = src_dict.copy()
        parameter_values = []
        _parameter_values = d.pop("parameterValues")
        for parameter_values_item_data in (_parameter_values):
            parameter_values_item = ExtensionParameterValue.from_dict(parameter_values_item_data)



            parameter_values.append(parameter_values_item)


        create_extension_instance = cls(
            parameter_values=parameter_values,
        )

        return create_extension_instance




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.auto_stop import AutoStop





T = TypeVar("T", bound="CreateDatabaseInitialCluster")


@_attrs_define
class CreateDatabaseInitialCluster:
    """ 
        Attributes:
            name (str):
            size (str):
            auto_stop (Union[Unset, AutoStop]):
     """

    name: str
    size: str
    auto_stop: Union[Unset, 'AutoStop'] = UNSET


    def to_dict(self) -> Dict[str, Any]:
        from ..models.auto_stop import AutoStop
        name = self.name

        size = self.size

        auto_stop: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.auto_stop, Unset):
            auto_stop = self.auto_stop.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "name": name,
            "size": size,
        })
        if auto_stop is not UNSET:
            field_dict["autoStop"] = auto_stop

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.auto_stop import AutoStop
        d = src_dict.copy()
        name = d.pop("name")

        size = d.pop("size")

        _auto_stop = d.pop("autoStop", UNSET)
        auto_stop: Union[Unset, AutoStop]
        if isinstance(_auto_stop,  Unset):
            auto_stop = UNSET
        else:
            auto_stop = AutoStop.from_dict(_auto_stop)




        create_database_initial_cluster = cls(
            name=name,
            size=size,
            auto_stop=auto_stop,
        )

        return create_database_initial_cluster




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

if TYPE_CHECKING:
  from ..models.extension_version import ExtensionVersion





T = TypeVar("T", bound="Extension")


@_attrs_define
class Extension:
    """ 
        Attributes:
            id (str):
            name (str):
            description (str):
            category_id (str):
            installable_versions (List['ExtensionVersion']):
     """

    id: str
    name: str
    description: str
    category_id: str
    installable_versions: List['ExtensionVersion']


    def to_dict(self) -> Dict[str, Any]:
        from ..models.extension_version import ExtensionVersion
        id = self.id

        name = self.name

        description = self.description

        category_id = self.category_id

        installable_versions = []
        for installable_versions_item_data in self.installable_versions:
            installable_versions_item = installable_versions_item_data.to_dict()
            installable_versions.append(installable_versions_item)






        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "id": id,
            "name": name,
            "description": description,
            "categoryId": category_id,
            "installableVersions": installable_versions,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.extension_version import ExtensionVersion
        d = src_dict.copy()
        id = d.pop("id")

        name = d.pop("name")

        description = d.pop("description")

        category_id = d.pop("categoryId")

        installable_versions = []
        _installable_versions = d.pop("installableVersions")
        for installable_versions_item_data in (_installable_versions):
            installable_versions_item = ExtensionVersion.from_dict(installable_versions_item_data)



            installable_versions.append(installable_versions_item)


        extension = cls(
            id=id,
            name=name,
            description=description,
            category_id=category_id,
            installable_versions=installable_versions,
        )

        return extension




import datetime
from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import (
    UNSET,
    Unset,
)

T = TypeVar("T", bound="File")


@_attrs_define
class File:
    """ 
        Attributes:
            name (str):
            type (str):
            path (str):
            last_modified (datetime.datetime):
            size (Union[Unset, int]):
            children (Union[Unset, List['File']]):
     """

    name: str
    type: str
    path: str
    last_modified: datetime.datetime
    size: Union[Unset, int] = UNSET
    children: Union[Unset, List['File']] = UNSET


    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        type = self.type

        path = self.path

        last_modified = self.last_modified.isoformat()

        size = self.size

        children: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.children, Unset):
            children = []
            for children_item_data in self.children:
                children_item = children_item_data.to_dict()
                children.append(children_item)






        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "name": name,
            "type": type,
            "path": path,
            "lastModified": last_modified,
        })
        if size is not UNSET:
            field_dict["size"] = size
        if children is not UNSET:
            field_dict["children"] = children

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        type = d.pop("type")

        path = d.pop("path")

        last_modified = isoparse(d.pop("lastModified"))




        size = d.pop("size", UNSET)

        children = []
        _children = d.pop("children", UNSET)
        for children_item_data in (_children or []):
            children_item = File.from_dict(children_item_data)



            children.append(children_item)


        file = cls(
            name=name,
            type=type,
            path=path,
            last_modified=last_modified,
            size=size,
            children=children,
        )

        return file




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

T = TypeVar("T", bound="AutoStop")


@_attrs_define
class AutoStop:
    """ 
        Attributes:
            enabled (bool):
            idle_time (int):
     """

    enabled: bool
    idle_time: int


    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled

        idle_time = self.idle_time


        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "enabled": enabled,
            "idleTime": idle_time,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        enabled = d.pop("enabled")

        idle_time = d.pop("idleTime")

        auto_stop = cls(
            enabled=enabled,
            idle_time=idle_time,
        )

        return auto_stop




from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import (
    UNSET,
    Unset,
)

T = TypeVar("T", bound="ExtensionVersion")


@_attrs_define
class ExtensionVersion:
    """ 
        Attributes:
            version (str):
            latest (bool):
            deprecated (bool):
            installed (bool):
     """

    version: str
    latest: bool
    deprecated: bool
    installed: bool


    def to_dict(self) -> Dict[str, Any]:
        version = self.version

        latest = self.latest

        deprecated = self.deprecated

        installed = self.installed


        field_dict: Dict[str, Any] = {}
        field_dict.update({
            "version": version,
            "latest": latest,
            "deprecated": deprecated,
            "installed": installed,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        version = d.pop("version")

        latest = d.pop("latest")

        deprecated = d.pop("deprecated")

        installed = d.pop("installed")

        extension_version = cls(
            version=version,
            latest=latest,
            deprecated=deprecated,
            installed=installed,
        )

        return extension_version

